@@ -391,10 +391,14 @@ class ProjectSettings(flow.Object):
     non_editable_files = flow.Param("")
     auto_upload = flow.Param('').ui(
         tooltip='Enable <b>upload after publish</b> by default for all files matching the provided patterns')
+    hide_upload_after_publish = flow.Param('')
     clean_zip_files = flow.Child(CleanZipFiles).ui(label='Clean ZIP files')
 
     def get_auto_upload_files(self):
         return self.auto_upload.get().replace(' ', '').split(',')
+    
+    def get_hidden_upload_files(self):
+        return self.hide_upload_after_publish.get().replace(' ', '').split(',')
 
 
 class ExchangeSiteChoiceValue(flow.values.ChoiceValue):
