@@ -27,14 +27,14 @@ class KitsuAPIWrapper(flow.Object):
 
     def log_in(self, username, password):
         try:
-            gazu.log_in(username, password)
+            user_data = gazu.log_in(username, password)
         except (
             gazu.exception.AuthFailedException,
             gazu.exception.ServerErrorException,
         ):
-            return False
+            user_data = None
 
-        return True
+        return user_data
     
     def log_out(self):
         gazu.log_out()
